# Security Policy

## Supported Versions

Only the latest version of `financeindia` is supported for security updates.

| Version | Supported          |
| ------- | ------------------ |
| v0.1.x  | :white_check_mark: |
| < v0.1  | :x:                |

## Reporting a Vulnerability

We take the security of `financeindia` seriously. If you believe you have found a security vulnerability, please report it to us privately.

**Please do not report security vulnerabilities via public GitHub issues.**

Instead, please send an email to: [security@nseindia.com](mailto:security@nseindia.com)

You should receive a response within 48 hours. If the issue is confirmed, we will coordinate a fix and a release before making a public disclosure.

Thank you for helping keep `financeindia` safe for the community!
